@@ -11,7 +11,7 @@ module GrapePathHelpers
     end
 
     def all_routes
-      routes = subclasses.flat_map { |s| s.send(:prepare_routes) }
+      routes = descendants.flat_map { |s| s.send(:prepare_routes) }
       routes.uniq { |r| r.options.merge(path: r.path) }
     end
   end
